@@ -34,7 +34,7 @@ class KCMKScreen : public KQuickAddons::ConfigModule
     Q_PROPERTY(bool tabletModeAvailable READ tabletModeAvailable NOTIFY tabletModeAvailableChanged)
 
 public:
-    explicit KCMKScreen(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit KCMKScreen(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~KCMKScreen() override = default;
 
     void load() override;
@@ -68,6 +68,9 @@ public:
     void doSave(bool force);
     Q_INVOKABLE void revertSettings();
 
+    Q_INVOKABLE void setStopUpdatesFromBackend(bool value);
+    Q_INVOKABLE void updateFromBackend();
+
 Q_SIGNALS:
     void backendReadyChanged();
     void backendError();
@@ -100,11 +103,12 @@ private:
     void continueNeedsSaveCheck(bool needs);
 
     std::unique_ptr<OutputIdentifier> m_outputIdentifier;
-    std::unique_ptr<ConfigHandler> m_config;
+    std::unique_ptr<ConfigHandler> m_configHandler;
     OrientationSensor *m_orientationSensor;
     bool m_backendReady = false;
     bool m_screenNormalized = true;
     bool m_settingsReverted = false;
+    bool m_stopUpdatesFromBackend = false;
     double m_globalScale = 1.;
     double m_initialGlobalScale = 1.;
 
