@@ -7,6 +7,7 @@
 
 #include "../common/utils.h"
 
+#include <kscreen/edid.h>
 #include <kscreen/output.h>
 
 #include <QQuickItem>
@@ -23,7 +24,8 @@ OutputIdentifier::OutputIdentifier(KScreen::ConfigPtr config, QObject *parent)
 {
     const QString qmlPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral(QML_PATH "OutputIdentifier.qml"));
 
-    for (const auto &output : config->connectedOutputs()) {
+    const auto outputs = config->connectedOutputs();
+    for (const auto &output : outputs) {
         if (!output->currentMode()) {
             continue;
         }
@@ -47,25 +49,26 @@ OutputIdentifier::OutputIdentifier(KScreen::ConfigPtr config, QObject *parent)
             continue;
         }
 
-        QSize deviceSize, logicalSize;
-        if (output->isHorizontal()) {
-            deviceSize = mode->size();
-        } else {
-            deviceSize = QSize(mode->size().height(), mode->size().width());
+        QSize logicalSize = config->logicalSizeForOutput(*output.data()).toSize();
+        if (!(config->supportedFeatures() & KScreen::Config::Feature::PerOutputScaling)) {
+            logicalSize = logicalSize / view->effectiveDevicePixelRatio();
         }
-        if (config->supportedFeatures() & KScreen::Config::Feature::PerOutputScaling) {
-            // Scale adjustment is not needed on Wayland, we use logical size.
-            logicalSize = output->logicalSize().toSize();
-        } else {
-            logicalSize = deviceSize / view->effectiveDevicePixelRatio();
+
+        bool shouldShowSerialNumber = false;
+        if (output->edid()) {
+            shouldShowSerialNumber = std::any_of(outputs.cbegin(), outputs.cend(), [output](const auto &other) {
+                return other->id() != output->id() // avoid same output
+                    && other->edid() && other->edid()->name() == output->edid()->name() && other->edid()->vendor() == output->edid()->vendor();
+            });
         }
-        rootObj->setProperty("outputName", Utils::outputName(output));
-        rootObj->setProperty("modeName", Utils::sizeToString(deviceSize));
+        rootObj->setProperty("outputName", Utils::outputName(output, shouldShowSerialNumber));
+        rootObj->setProperty("resolution", output->currentMode()->size());
+        rootObj->setProperty("scale", output->scale());
         view->setProperty("screenSize", QRect(output->pos(), logicalSize));
         m_views << view;
     }
 
-    for (auto *view : m_views) {
+    for (auto *view : qAsConst(m_views)) {
         view->show();
     }
     QTimer::singleShot(2500, this, &OutputIdentifier::identifiersFinished);
