@@ -32,11 +32,11 @@ public:
     explicit OsdAction(QObject *parent = nullptr);
 
     Q_INVOKABLE QVector<int> actionOrder() const;
-    Q_INVOKABLE QString actionLabel(Action action) const;
-    Q_INVOKABLE QString actionIconName(Action action) const;
+    Q_INVOKABLE QString actionLabel(KScreen::OsdAction::Action action) const;
+    Q_INVOKABLE QString actionIconName(KScreen::OsdAction::Action action) const;
 
 Q_SIGNALS:
-    void selected(Action action);
+    void selected(KScreen::OsdAction::Action action);
 };
 
 } // namespace KScreen
